;*****************************************************************************
;
; Subroutine to convert an unsigned byte into a 3 byte decimal value
; please note the input value is destroyed in the conversion process
;
; Program	BYT2ASC.INC
; Author	Wim de Vree, pe1grl@planet.nl	
; Revision history
; 19990623	Created, based upon the 16 bit code (WRD2ASC)
; 19990929	Obscured local labels to avoid conflicts
; 20030709	Save/Unsave FSR added
;	
; Used resources:
;		SCRATCH		< 4 bytes>
;		B2A_RESULT	< 3 bytes>
;
; Usage:
;		SCRATCH 	equ 0x10	; workspace, 3 bytes required
;						; place input at scratch
;						; destroyed in conversion
;		B2A_RESULT	equ 0x20	; result will be placed here,
;						; 3 bytes required, high to low order
;
;		movlw	0xFA			; Input MSB
;		movwf	(SCRATCH)
;		call	BYT2ASC
;
;
;
;*****************************************************************************
; Equates used by subroutines
;*****************************************************************************
B2A_number	equ	(SCRATCH)	; high byte binary input  value
B2A_index	equ	(SCRATCH+2)
B2A_dig_ctr	equ	(SCRATCH+3)
B2A_fsr		equ	(SCRATCH+4)

B2A_hund	equ	(B2A_RESULT)
B2A_ten		equ	(B2A_RESULT+1)
B2A_one		equ	(B2A_RESULT+2)

;------------------------------------------------------------------------
;END BYTE TO ASCII CONVERSION
;------------------------------------------------------------------------
B2A_table	addwf	PCL,f		; add index to program counter
		retlw	0x64		;    100 decimal
		retlw	0x0a		;     10 decimal
;-----------------------------------------------------------------------
BYT2ASC		movwf	B2A_number
		movlw	0x30		; init result with ASCII '0'
		movwf	B2A_hund
		movwf	B2A_ten
		movwf	B2A_one
		clrf	B2A_index	; init work registers
		clrf	B2A_dig_ctr
		movf	FSR,W
		movwf	B2A_fsr		; Save FSR contents
B2A_subtr	movf	B2A_index,w	; get current index into W
		call	B2A_table	; get chunk for subtraction
		subwf	B2A_number,f
		btfsc	STATUS,C	; test carry flag
		goto	B2A_incdig
		movlw	B2A_RESULT	; load base address of table
		movwf	FSR
		movf	B2A_index,w	; get index
		addwf	FSR,f		; add offset
		movf	B2A_dig_ctr,w	; get digit counter contents
		addwf	INDF,f		; add to '0' at digit loc (indexed)
		movf	B2A_index,w	; get index
		call	B2A_table	; get chunk for addition
		addwf	B2A_number,f	; add back
		movf	B2A_index,w	; get index
		sublw	0x01		; index = 1
		btfsc	STATUS,Z
		goto	B2A_finish
		incf	B2A_index,f
		clrf	B2A_dig_ctr
		goto	B2A_subtr
;------------------------------------------
B2A_incdig	incf	B2A_dig_ctr,f	; increment digit counter
		goto	B2A_subtr
;------------------------------------------
B2A_finish	movf	B2A_number,w	; get 1's = remainder
		addwf	B2A_one,f	; add to '0'
		movf	B2A_fsr,w
		movwf	FSR		; restore FSR
		return			; done
;------------------------------------------------------------------------
;END BYTE TO ASCII CONVERSION
;------------------------------------------------------------------------
