;*****************************************************************************
; MACROS:	Some Common MACROS
;
; Author	Wim de Vree, pe1grl@amsat.org
; Revision history
; 2000-05-07	Created, assembled from various other files
; 2003-07-16	Special version for 16F819 (has 4 banks)
; 2004-11-06	Added "smart" BANK switch macros, saves opcodes
;		if you know from which bank you are switching to
;		which bank (e.g. from Bank0->Bank2 can be done with
;		just setting one bit)
;
; Used resources:
;		NONE
;
; Usage:
;		BANK0	: Switch to bank 0
;		BANK1	: Switch to bank 1
;		BANK2	: Switch to bank 2
;		BANK3	: Switch to bank 3
;		NOP3	: 3 no-ops
;		NOP5	; 5 no-ops
;
	ifndef	MACROS_INCLUDED
#define	MACROS_INCLUDED			; Macros are included

BANK0:	MACRO
	ERRORLEVEL	+302		; enable warning "register is in bank 1"
	bcf	STATUS,RP0
	bcf	STATUS,RP1
	ENDM

BANK1:	MACRO
	ERRORLEVEL	-302		; disable warning "register is in bank x"
	bsf	STATUS,RP0
	bcf	STATUS,RP1
	ENDM
	
BANK2:	MACRO
	ERRORLEVEL	-302		; disable warning "register is in bank x"
	bcf	STATUS,RP0
	bsf	STATUS,RP1
	ENDM

BANK3:	MACRO
	ERRORLEVEL	-302		; disable warning "register is in bank x"
	bsf	STATUS,RP0
	bsf	STATUS,RP1
	ENDM

BANK01:	MACRO				; switch from BANK0 to BANK1
	ERRORLEVEL	-302		; disable warning "register is in bank n"
	bsf	STATUS,RP0
	ENDM

BANK02:	MACRO				; switch from BANK0 to BANK2
	ERRORLEVEL	-302		; disable warning "register is in bank n"
	bsf	STATUS,RP1
	ENDM

BANK10:	MACRO				; switch from BANK1 to BANK0
	ERRORLEVEL	+302		; enable warning "register is in bank n"
	bcf	STATUS,RP0
	ENDM

BANK20:	MACRO				; switch from BANK3 to BANK0
	ERRORLEVEL	+302		; enable warning "register is in bank n"
	bcf	STATUS,RP1
	ENDM

BANK23:	MACRO				; switch from BANK2 to BANK3
	bsf	STATUS,RP0
	ENDM

BANK32:	MACRO				; switch from BANK3 to BANK2
	bcf	STATUS,RP0
	ENDM

NOP3:	MACRO
	nop
	nop
	nop
	ENDM

NOP5:	MACRO
	nop
	nop
	nop
	nop
	nop
	ENDM

INT_ON	MACRO
	bsf	INTCON, GIE
	ENDM	

INT_OFF	MACRO
	bcf	INTCON, GIE	; disable interrupts
	btfsc	INTCON, GIE
	 goto	$-2		; loop until they are REALLY off
	ENDM

COPY32	MACRO	SRC, DST
	movfw	SRC
	movwf	DST
	movfw	SRC+1
	movwf	DST+1
	movfw	SRC+2
	movwf	DST+2
	movfw	SRC+3
	movwf	DST+3
	ENDM
	
#endif
